@@ -297,7 +297,7 @@ AutoComplete.prototype.search = function(str) {
                         display_name: pattern, email1: pattern,
                         email2: pattern, email3: pattern, last_name: pattern,
                         first_name: pattern, folder: allFolder, orSearch: true,
-                        emailAutoComplete: true
+                        emailAutoComplete: parent.emailAutoComplete
                     }
                 }];
                 
@@ -363,6 +363,13 @@ AutoComplete.prototype.search = function(str) {
  */
 AutoComplete.prototype.columns = "1,500,555,556,557,524,602,592,20";
 
+/**
+ * emailAutoComplete parameter for the contact search request.
+ * Specifies whether to return only contacts with at least one valid e-mail
+ * address.
+ */
+AutoComplete.prototype.emailAutoComplete = true;
+
 /**
  * A callback which is called for every new contact retrieved from the server.
  * This function should add the contact to this.cache and, if it is used,
@@ -455,21 +462,32 @@ function AutoCompleteCache() {
     this.aStr = new Object();
 }
 
-AutoCompleteCache.prototype.add = function(key, addresses) {
-    this.aStr[key] = addresses;
+/**
+ * Adds an entry to the autocomplete cache.
+ * @param {String} key The key which is used to recognize duplicate entries.
+ * @param {Array} addresses An array of addresses which will be returned by
+ * getResults for this entry.
+ * @param {String} displayName The text used to display the entry and to match
+ * it against user input. Defaults to the same value as the key.
+ */
+AutoCompleteCache.prototype.add = function(key, addresses, displayName) {
+    this.aStr[key] = { displayName: displayName || key, addresses: addresses };
 };
 
 AutoCompleteCache.prototype.getResults = function(str, outStr) {
+    // quote string for regex but fix wilcards
+    // this reflects what the server does: the search pattern must start
+    // at the begin or after whitespaces or "<" (email addresses)
+    // additionally, display names might be quoted
+    var resultRegex = "(^\"?|.*(\\s|<))"+escapeRegExp(str).replace(/\\\*/g, '.*').replace(/\\\?/g, '.');
+    var re = new RegExp(resultRegex, "i");
     for (var i in this.aStr) {
-        // quote string for regex but fix wilcards
-        // this reflects what the server does: the search pattern must start
-        // at the begin or after whitespaces or "<" (email addresses)
-        // additionally, display names might be quoted
-        var resultRegex = "(^\"?|.*(\\s|<))"+escapeRegExp(str).replace(/\\\*/g, '.*').replace(/\\\?/g, '.');
-        var re = new RegExp(resultRegex, "i");
-        var obj = {};
-        obj[i] = this.aStr[i];
-        if (i.match(re)) outStr.push(obj);
+        var name = this.aStr[i].displayName;
+        if (name.match(re)) {
+            var obj = {};
+            obj[name] = this.aStr[i].addresses;
+            outStr.push(obj);
+        }
     }
 };
 
