@@ -593,19 +593,19 @@ monthView.prototype = {
 					endDate.getUTCMinutes() == 0 &&
 								endDate.getUTCMilliseconds() == 0) {
 				nDaysMultiDay--;
-			}	
-			var oCurrDayIter = new Date(startDate);				
+			}
+			var oCurrDayIter = new Date(startDate);
 			for (var nNumDay=0; nNumDay<=nDaysMultiDay; nNumDay++) {
 				//do nothing at start day - that's default case
 				if (nNumDay != 0) {
-					this.doDrawAppointment(oCurrDayIter, calendarObjects, index, nNumDay<nDaysMultiDay);				
+					this.doDrawAppointment(oCurrDayIter, calendarObjects, index, { total: nDaysMultiDay, index: nNumDay });
 				}
 				oCurrDayIter.setUTCDate(oCurrDayIter.getUTCDate()+1);
                 oCurrDayIter.setTime(Math.floor(oCurrDayIter.getTime() / 864e5) * 864e5); // ms / day
 			}
 		}
 		
-		this.doDrawAppointment(startDate, calendarObjects, index, false);
+		this.doDrawAppointment(startDate, calendarObjects, index, nDaysMultiDay ? { total: nDaysMultiDay, index: 0 } : null);
 	},
 	
 	redrawAppointments: function(workWeekHeight,weekEndHeight) {
@@ -970,7 +970,13 @@ monthView.prototype = {
 		var isPrivateShared = (owner !== configGetKey('identifier') && calendarObjects.private_flag === true);
 		
 		var appointmentDate = new Date(calendarObjects.start_date);
-		if (isMultiday) appointmentDate.setUTCMinutes(0);
+		if (isMultiday) {
+		    if (isMultiday.index === isMultiday.total) {
+		        appointmentDate = new Date(calendarObjects.end_date);
+		    } else {
+		        appointmentDate.setUTCMinutes(0);
+		    }
+		}
 		var formattedTime = formatDate(appointmentDate, "time");	
 		var shownDiv = getShownDiv(calendarObjects.shown_as);
 	
@@ -992,8 +998,11 @@ monthView.prototype = {
 						
 		var textDiv = newnode("div", { overflow: "hidden" }, 
 					{ className: "showAppointmentTextMonth" + (fullday ? "Full" : "") + " dateCalendarFontSize" });
-	
-		var timeDisplayString = (!fullday && !isMultiday ? formattedTime : "") + " " + (calendarObjects.title || "");		
+		
+		var timeDisplayString = calendarObjects.title || "";
+		if (!fullday && (!isMultiday || isMultiday && (isMultiday.index === 0 || isMultiday.index === isMultiday.total))) {
+		    timeDisplayString = " " + formattedTime + " " + timeDisplayString;
+		}
 		
 		if (calendarObjects.location) {
 			timeDisplayString += " - " + calendarObjects.location;
@@ -1023,7 +1032,16 @@ monthView.prototype = {
 				}
 			}
 		}
-
+		if (isMultiday) {
+		    var multi = jQuery('<div>').css({ fontSize: "180%", 'float': "left", marginRight: "2px" }).appendTo(textDiv);
+		    if (isMultiday.index === isMultiday.total) {
+		        multi.append(document.createTextNode('\u21e5'));
+		    } else if (isMultiday.index === 0) {
+		        multi.append(document.createTextNode('\u21e4'));
+		    } else {
+		        multi.append(document.createTextNode('\u21ae'));
+		    }
+		}
 		textDiv.appendChild(document.createTextNode(timeDisplayString));
 		
 		datDIV.appendChild(shownDiv);		
