@@ -195,7 +195,34 @@ register("OX_Configuration_Loaded", function () {
 	    	);
 	    };
 	    
+	    function checkFields(data) {
+            function check(name, field, text) {
+                if (data[name] != "") return false;
+                field.formnode.focus();
+                setTimeout(function() { 
+                    //#. %1$s is the field name.
+                    //#, c-format
+                    triggerEvent("OX_New_Error", 4, format(
+                        _("The mandatory field %1$s is not defined."), text)); 
+                }, 0);
+                return true;
+            }
+            return (
+                check("name",            name,            _("Account Name"))  ||
+                check("primary_address", primary_address, _("E-Mail Address"))||
+                check("mail_server",     mail_server,     _("Server Name"))   ||
+                check("login",           login,           _("Login"))         ||
+                check("transport_login", transport_login, _("Login"))         ||
+                split.id === undefined && (
+                    check("password",    password,        _("Password"))      ||
+                    check("transport_password", transport_password,
+                                                          _("Password")))
+            );
+	    }
+	    
 	    split.save = function(data, cont) {
+            if (checkFields(data)) return;
+            
 	    	var nData = clone(data);
 	    	
 	    	// remove some fields if required
@@ -593,10 +620,11 @@ register("OX_Configuration_Loaded", function () {
 	    
 	    var check_button = new ox.UI.Button(_("Check connection"));
 	    check_button.click = function () {
+            var data = clone(split.get());
+            if (checkFields(data)) return;
 	        // pending...
 	    	newAlert(_("Info"), _("Please wait while checking the connection ... This may take a while ..."));
 	    	$(globalalert.visibleButtons[0].id).style.display="none";
-	    	var data = clone(split.get());
 	    	if (selection.getSelected().length == 1) {
 	    		data.id = selection.getSelected()[0];
 	    		if ("password" in data === false 
@@ -629,39 +657,7 @@ register("OX_Configuration_Loaded", function () {
         });
 	    
 	    var save_button = new ox.UI.Button(_("Save"));
-	    save_button.click = function(data, pata) {
-	    	function fail(field) {
-	    		setTimeout(function() { 
-	    		    //#. %1$s is the field name.
-	    		    //#, c-format
-	    			triggerEvent("OX_New_Error", 4, format(_("The mandatory field %1$s is not defined."), field)); 
-	    		}, 0);
-	    		return;
-	    	}
-	    	if (name.get() == "") {
-	    		name.formnode.focus();
-	    		return fail(_("Account Name"));
-	    	} else if (primary_address.get() == "") {	  
-	    		primary_address.formnode.focus();
-	    		return fail(_("E-Mail Address"));	 
-	    	} else if (mail_server.get() == "") {
-	    		mail_server.formnode.focus();
-	    		return fail(_("Server Name"));
-    		} else if (login.isEnabled && login.get() == "") {
-	    		login.formnode.focus();
-	    		return fail(_("Login"));
-    		} else if (!split["id"] && password.isEnabled && password.get() == "") {
-    			password.formnode.focus();
-	    		return fail(_("Password"));
-    		} else if (transport_login.isEnabled && transport_login.get() == "") {
-                transport_login.formnode.focus();
-                return fail(_("Login"));
-            } else if (!split["id"] && transport_password.isEnabled && transport_password.get() == "") {
-                transport_password.formnode.focus();
-                return fail(_("Password"));
-            }
-	    	split.saveView();
-	    };
+        save_button.click = function() { split.saveView(); };
 	    buttons.addWidget(save_button);
 	
 	    var cancel_button = new ox.UI.Button(_("Cancel"));
