@@ -96,9 +96,9 @@ register("OX_Configuration_Loaded_Complete", function() {
             getFullImgSrc("img/menu/add_category.gif"),
             getFullImgSrc("img/menu/add_category_d.gif"),
             function() {
-                split.addNew({ displayName: _("New messaging service")
-                                });
+                split.addNew({ displayName: _("New messaging service") });
                 setFocus(name.formnode);
+                split.listModified = true;
             });
         MenuNodes.createSmallButton(menu, "messaging.account.remove",
             _("Remove"),
@@ -246,6 +246,11 @@ register("OX_Configuration_Loaded_Complete", function() {
                         ox.api.folder.getSubFolders({ folder: 1, cache: false, success: function() {
                             ox.api.folder.dispatcher.trigger("modify");
                         }});
+                        // re-select for edit
+                        if (storage.ids.length >= 0) {
+                            split.list.focus = storage.ids.length-1;
+                            split.list.selection.click(storage.ids.length-1);
+                        }
                         track({
                             type: "new",
                             what: "social_account",
