@@ -146,7 +146,7 @@ function enableOAuth() {
                     icons: ["img/menu/delete.gif", "img/menu/delete_d.gif"],
                     action: confirmDelete
                 }]
-            }]);
+            }], "accounts");
 
         var servicesCB = new ox.UI.ComboBox(_("Service"));
         services.then(function(map, array) {
