@@ -1442,7 +1442,8 @@ ox.Configuration.VSplit.prototype = extend(ox.Configuration.View,
         },
 
         viewModified: function() {
-            return this.listModified || !equals(this.get(), this.original);
+            return this.listModified ||
+                ("original" in this) && !equals(this.get(), this.original);
         },
 
         enter: function() {
@@ -1678,7 +1679,7 @@ ox.Configuration.Page.prototype = extend(ox.Configuration.View,
         addCells: ox.Configuration.VSplit.prototype.addCells,
         
         viewModified: function() {
-            return !equals(this.get(), this.original);
+            return ("original" in this) && !equals(this.get(), this.original);
         },
 
         enter: function() {
