@@ -19,7 +19,7 @@ var contactsCardsRequest2;
 var contactsFolderPath;
 
 var contactJson = new JSONX();
-var tmpDetailRequest=null;
+var tmpDetailRequest=null, contactsSearchObject = null;
 /********************************** register Modules *****************************************************************/
 
 var contacts_phonelist_first=true;
@@ -66,6 +66,7 @@ registerView("contacts",
         };
 	},
 	function() {
+	    contactsSearchObject = null;
 	    ox.widgets.searchField.active().searchMenu.setFields();
 		if(tmpDetailRequest) {
             OXCache.unregister(tmpDetailRequest.uniqueName);
@@ -120,6 +121,7 @@ registerView("contacts/phonelist",
 		hideNode("contactsList");
 	},
 	function() {
+	    triggerEvent('OX_Delete_Search');
 		myLetterContactTab.buildTab("listeContactsLetterDiv");
 		initLiveGridContacts();
 	}
@@ -204,6 +206,7 @@ registerView("contacts/cards",
 			objContactFunctions.refHover.disable();
 	},
 	function() {
+	    triggerEvent('OX_Delete_Search');
 		contactsSelection2.reset();
 		objContactFunctions.resetContactCardCache();
 		scrollerCbar.scrollLeft = 0;
@@ -238,12 +241,13 @@ registerView("contacts/detail",
         unregister("OX_New_Search", contactsDetailSearch);
 	},
 	function() {
+	    triggerEvent('OX_Delete_Search');
 		objContactFunctions.loadingContactDetail(false);
 		objContactFunctions.clearDetailFields();
 		hideNode("contactDetails");
 		unregister("OX_Print",contacts_printDetail);
 		if(oDistributionLiveGrid.dlGrid && oDistributionLiveGrid.dlGrid.storage) {
-			oDistributionLiveGrid.dlGrid.disable()
+			oDistributionLiveGrid.dlGrid.disable();
 		}
 	}
 );
@@ -1085,8 +1089,11 @@ function showContactCards()
 	}
 	$("cardtmpl").style.display = "none";
 
-	cardsToView = cardsPerRowToView*4;
-    objContactFunctions.getStorageCache(undefined, undefined,
+	cardsToView = cardsPerRowToView*4, pattern = undefined;
+	if (contactsSearchObject !== null) {
+	    pattern = contactsSearchObject.pattern;
+	}
+    objContactFunctions.getStorageCache(pattern, pattern !== undefined ? true : undefined,
         ox.api.config.get("language").substring(0, 3) == "zh_" ? "gbk" : "");
 
 	scrollerCbar = $("contactCardScrollerbar");
@@ -2303,7 +2310,11 @@ function initLiveGridOnLoad()
 
 function initLiveGridContacts()
 {
-		objContactFunctions.getStorageCache();
+    var pattern = undefined;
+    if (contactsSearchObject !== null) {
+        pattern = contactsSearchObject.pattern;
+    }
+	objContactFunctions.getStorageCache(pattern, pattern !== undefined ? true : undefined);
 }
 
 /********************************** New Contact *****************************************************************/
@@ -2605,15 +2616,18 @@ function contact_HeaderUpdate(data) {
 
 var myLetterContactTab = new LetterContactTab();
 function searchContactByString(sModule,sPattern) {
+    contactsSearchObject = { module: sModule, pattern: sPattern };
 	objContactFunctions.getStorageCache(sPattern, true);
 }
 
 function contactsDetailSearch(module, pattern) {
+    contactsSearchObject = { module: module, pattern: pattern };
     objContactFunctions.searchHack = { pattern: pattern, fullsearch: true };
     switchtoView(menulastviews[module]);
 }
 
 function deleteSearchContactByString() {
+    contactsSearchObject = null;
     // reset storage
 	if (viewContactsBySearch.fullSearch) {
 	    viewContactsBySearch.fullSearch = false;
