@@ -514,7 +514,8 @@ NewContactFunctions.prototype = {
     			folderViewSettingsNewContact["calendar"] = 4;
     			folderViewSettingsNewContact["tasks"] = 4;
     			folderViewSettingsNewContact["infostore"] = 4;
-    			if(!contactTreeLoaded){
+    			if(!contactTreeLoaded) {
+    			    addOnClose($("treeDialogNewContact"), toggleTree);
     				ox.api.ui.selectFolder({
     			    	type: "contacts",
     			    	id: "select-folder-popup-contacts",
@@ -556,33 +557,20 @@ function folderAction(data) {
 	});
 }
 
-function showTree(){
-	centerPopupWindow($("treeDialogNewContact"));
-	$("treeDialogNewContact").style.display = "block";
-	$("treeDialogNewContact").style.top = "120px";
-	$("treeDialogNewContact").style.left = "170px";
-}
-function hideTree(){
-	$("treeDialogNewContact").style.display = "none";
-}
-
 function toggleTree(){
-	if(newContactFolderTree == null)
-	{
+	if (newContactFolderTree == null) {
 		myNewContactFunctions.folderPath();
 	}
-	if(!treeVisible){
-		centerPopupWindow($("treeDialogNewContact"));
+	if (!treeVisible){
+		centerPopupWindow($("treeDialogNewContact"), 400, 300);
 		$("treeDialogNewContact").style.display = "block";
-		$("treeDialogNewContact").style.top = "120px";
-		$("treeDialogNewContact").style.left = "170px";
 		treeVisible = true;
 
-	}
-	else{
+	} else{
 		$("treeDialogNewContact").style.display = "none";
 		treeVisible = false;
 	}
+	ox.api.setModal(treeVisible);
 }
 
 /**
@@ -1515,7 +1503,10 @@ var eventList =
 
 
 function setBeforeUnload(on) {
-    messageOnCancel = on;
+    if (on !== undefined && on !== messageOnCancel) {
+        messageOnCancel = on;
+    }
+    ctrl.dirty(messageOnCancel);
 }
 
 // init window controller
@@ -1529,3 +1520,4 @@ ctrl.set("beforeunload", function () {
 });
 
 ctrl.set("confirm", NewContactFunctions.prototype.closeWindow);
+ctrl.set("dirty", setBeforeUnload);
