@@ -27,7 +27,7 @@ var mailFetchTimestamp;
 var detailrequest;
 var deleteMailIDs = emptyFunction;
 var deleteMails = emptyFunction;
-var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions, toggleImipTab;
+var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions, toggleImipTab, mailSearchObject = null;
 var openAttachment;
 
 function infostore_sendLink(obj) {
@@ -271,13 +271,18 @@ var setMailHeaderLabel;
             register("OX_Mail_Ham", oMailFunctions.markAsHam);
             register("OX_Mail_Show_Source", oMailFunctions.showMailSource);
 
+            setMailHeaderLabel();
             setSearch();
 
             ox.widgets.searchField.active().searchMenu.onChange = function() { };
 
         },
         function() {
-            if(detailrequest) {
+            mailSearchObject = null;
+            if (view && view.grid) {
+                view.grid.searchActive = false;
+            }
+            if (detailrequest) {
                 OXCache.unregister(detailrequest.uniqueName);
                 detailrequest=null;
             }
@@ -308,6 +313,7 @@ var setMailHeaderLabel;
      * @todo: needs to be optimized
      */
     function updateAfterDeleteSearch() {
+        mailSearchObject = null;
         if (!view.grid.searchActive) return;
         view.grid.searchActive=false;
         if(currentpath[2] == "threaded")
@@ -357,7 +363,11 @@ var setMailHeaderLabel;
                 } else if (view.grid.selection.getSelected().length > 0) {
                     view.grid.selection.selectIDs(view.grid.selection.getSelected());
                 }
-                updateMailStorage(param, undefined, type);
+                if (mailSearchObject !== null) {
+                    searchMail(mailSearchObject.sModule, mailSearchObject.pattern, mailSearchObject.field);
+                } else {
+                    updateMailStorage(param, undefined, type);
+                }
                 
                 // trigger selection event
                 triggerEvent("Selected", view.grid.selection.getSelected());
@@ -440,7 +450,7 @@ var setMailHeaderLabel;
     function switchGridHeaders(grid) {
         // update folder name and unread count information for grid header
         //setMailHeaderLabel();
-        view.grid.searchActive=false; // set search to inactive, not sure if
+//        view.grid.searchActive=false; // set search to inactive, not sure if
 
         var sent = isStdFolder("sent");
         var to = sent || isStdFolder("drafts");
@@ -649,6 +659,7 @@ var setMailHeaderLabel;
         }
         search.operator = "or";
         view.grid.searchActive=true;
+        mailSearchObject = { module: sModule, pattern: sPattern, field: field };
         view.grid.enable(criteria,search,false);
         mail_folderPath.drawSearch(sModule, sPattern);
     }
