@@ -91,7 +91,10 @@ function isIE() {
 
 var ums = false;
 function setBeforeUnload(on) {
-    ums = on;
+    if (on !== undefined && on !== ums) {
+        ums = on;
+    }
+    ctrl.dirty(ums);
 }
 
 function onChange() {
@@ -1173,7 +1176,7 @@ MailFunctions.prototype = {
             setModalBusy(true);
             tmp_attachmentDialog.do_post(Self.oo, callback_new, Self.sAction, sTargetParam, setModalBusy);
         }
-        if (!silent && trimStr(Self.oo.subject).length === 0) {
+        if (!silent && action !== "draft" && trimStr(Self.oo.subject).length === 0) {
             newInput(
                 _("Send"),
                 _("You did not enter a subject. Would you like to enter a subject now?"),
@@ -1215,10 +1218,10 @@ MailFunctions.prototype = {
             msgref = data;
             action = 'draft';
             setBeforeUnload(false);
+            oMailFunctionsNew.cleanUp(false);
             corewindow.updateDraftsFolderCache(url.id, data, activeMailAccount.id);
             if (!silent && (self.attachObj.length ||
-                editorEnabled && tinyMCE.activeEditor.dom.select("img").length))
-            {
+                editorEnabled && tinyMCE.activeEditor.dom.select("img").length)) {
                 cb_initMessageContent = callback || jQuery.noop;
                 url.folder = data.replace(/\/[^\/]+$/, "");
                 url.id = data.replace(/.*\//, "");
@@ -1267,9 +1270,9 @@ MailFunctions.prototype = {
                     autosave = reply.data;
                     if (autosave.indexOf("/") !== -1) {
                         // have to update mail id for all inline images
-                        self.updateInlineImages(
-                            autosave.substr(autosave.lastIndexOf("/")+1, autosave.length)
-                        );
+                        var i = autosave.lastIndexOf("/");
+                        self.updateInlineImages(autosave.slice(i + 1),
+                                                autosave.slice(0, i));
                     }
                     self = null;
                 }
@@ -1281,7 +1284,7 @@ MailFunctions.prototype = {
      * 
      * @param id - the new mail id
      */
-    updateInlineImages: function(id) {
+    updateInlineImages: function(id, folder) {
         if (editorEnabled) {
             // getting all images in editor
             jQuery("img", tinyMCE.activeEditor.dom.select("body")).filter(function() {
@@ -1293,6 +1296,7 @@ MailFunctions.prototype = {
                     var hash  = ox.util.deserialize(url[1]);
                     if ("id" in hash && "uid" in hash) {
                         hash.id = id;
+                        hash.folder = folder;
                         var url = url[0] + "?" + ox.util.serialize(hash);
                         jQuery(this).attr({ src: url, "data-mce-src": url});
                         url = null;
@@ -1302,11 +1306,13 @@ MailFunctions.prototype = {
         }
     },
 
-    cleanUp: function () {
+    cleanUp: function (resetInterval) {
         // reset intervals, specially IE does not reset
         // them when closing the iframe
-        for (var i=0; i < intervals.length; i++) {
-            window.clearInterval(intervals[i]);
+        if (resetInterval !== false) {
+            for (var i=0; i < intervals.length; i++) {
+                window.clearInterval(intervals[i]);
+            }
         }
         // delete autosave message if necessary
         if (autosave) {
@@ -1983,6 +1989,8 @@ var tinyMCEInit = function () {
         font_size_style_values : "8pt,10pt,12pt,14pt,18pt,24pt,36pt",
         width: "100%",
         height: "100%",
+//        table_default_border: 1,
+//        table_default_cellpadding: 5,
         setup: function (ed) {
             // key: enter
             ed.onKeyDown.add(function (ed, e) {
@@ -1997,6 +2005,10 @@ var tinyMCEInit = function () {
                     globalContextMenus.simpleAttachments.hide();
                 }
             });
+            
+//            ed.onBeforeExecCommand.add(function(ed, cmd, ui, val) {
+//                console.debug('Command is to be executed: ', ed, cmd, ui, val);
+//            });
         }
     };
     // start with empty controls
@@ -2212,3 +2224,4 @@ ctrl.set("beforeunload", function () {
 });
 
 ctrl.set("confirm", askToClose);
+ctrl.set("dirty", setBeforeUnload);
\ No newline at end of file
