@@ -107,6 +107,9 @@ registerView("task_new/task",
 	function() {
         if ((corewindow.ox.upsell.isVisible("infostore") && corewindow.ox.upsell.isVisible("tasks-attachments")) === false) {
             $("panel4").style.display = "none";
+        }
+        if (!corewindow.ox.upsell.isVisible("delegate")) {
+            $("panel3").style.display = "none";
         }
 		$("tab1").style.display="block";
 		$("panel1").className="tabPanelFirstHi tabPanelHiColor background-color-content font-style-lable border-color-content-default";	
@@ -619,19 +622,19 @@ function readTaskFields() {
 	} catch (e) { }
 	
 	var tmpval = trimStr($("target_costs").value);
-	if (tmpval.length != 0 && tmpval > 130000 || tmpval < -130000) {
+	if (tmpval.length != 0 && tmpval > 999999999999.99 || tmpval < -999999999999.99) {
 	    //#. %s is a field name (estimated costs or current costs).
 	    //#, c-format
-		error_msg = format(_("The entered value for %s is not within the allowed range. Please use a value from -130000 to 130000."), _("estimated costs"));
+		error_msg = format(_("The entered value for %s is not within the allowed range. Please use a value from -999999999999.99 to 999999999999.99."), _("estimated costs"));
 		allOk = 4;
 	} else if (tmpval != taskobject.target_costs || taskobject.target_costs != ta_object.target_costs) {
 		ta_object.target_costs = tmpval.length != 0 ? tmpval : null;
 	}
 	var tmpval = trimStr($("actual_costs").value);
-    if (tmpval.length != 0 && tmpval > 130000 || tmpval < -130000) {
+    if (tmpval.length != 0 && tmpval > 999999999999.99 || tmpval < -999999999999.99) {
         //#. %s is a field name (estimated costs or current costs).
         //#, c-format
-        error_msg = format(_("The entered value for %s is not within the allowed range. Please use a value from -130000 to 130000."), _("current costs"));
+        error_msg = format(_("The entered value for %s is not within the allowed range. Please use a value from -999999999999.99 to 999999999999.99."), _("current costs"));
         allOk = 4;
     } else if (tmpval != taskobject.actual_costs || taskobject.actual_costs != ta_object.actual_costs) {
 		ta_object.actual_costs = tmpval.length != 0 ? tmpval : null;
