@@ -249,20 +249,9 @@ ox.gui.FolderTree = ox.gui.Tree.extend({
                     || (data.folder_id === "0") || (data.module === "system" && src ==="mail" && this.options.type === "mail")) {
 
                 // sufficient permissions?
-                var sufficientPermissions = api.can("read", data);
-                // explicit permission check?
-                if (this.options.minPerms !== undefined) {
-                    var perms = data.own_rights;
-                    var mask = this.options.minPerms || 0;
-                    if (   (perms       & 127) < (mask       & 127)
-                        || (perms >>  7 & 127) < (mask >>  7 & 127)
-                        || (perms >> 14 & 127) < (mask >> 14 & 127)
-                        || (perms >> 21 & 127) < (mask >> 21 & 127)
-                        || (perms >> 28 &   1) < (mask >> 28 &   1)) {
-                        // insufficient permissions
-                        sufficientPermissions = false;
-                    }
-                }
+                var sufficientPermissions = api.can("read", data) &&
+                    // explicit permission check
+                    ox.api.folder.checkMinPerms(data, this.options.minPerms);
                 // folder has no read and write access
                 if (!sufficientPermissions && data.module !== "system" &&
                     data.module !== "infostore" || node.isCut)
@@ -623,19 +612,17 @@ ox.gui.FolderTreePopup = ox.gui.FolderTree.extend({
             api.get({
                 folder: e.data,
                 success: function (data) {
-                    // typed tree?
-                    if (opt.type !== undefined) {
-                        if (opt.type === data.module) {
+                    // checking minPermissions if set in the options
+                    if (ox.api.folder.checkMinPerms(data, opt.minPerms)) {
+                        // typed tree?
+                        if (opt.type !== undefined ? opt.type === data.module
+                                                   : data.module !== "system")
+                        {
                             callback(data);
                             if (opt.destroy === true) {
                                 self.destroy();
                             }
                         }
-                    } else if (data.module !== "system") {
-                        callback(data);
-                        if (opt.destroy === true) {
-                            self.destroy();
-                        }
                     }
                 }
             });
