@@ -823,8 +823,34 @@ com_openexchange_subscribe.func_button_refresh_subscription_folder = function(mo
                 return undefined;
             };
             // overwrite action
-            refresh.options.action = function() { 
-                refreshFolder(); 
+            refresh.options.action = function() {
+                var join = new Join(function() {
+                    refreshFolder();
+                });
+                var lock = join.add();
+                if (activemodule === "calendar") {
+                    ox.JSON.get(AjaxRoot +
+                            "/subscriptions?action=all&columns=id,displayName,enabled,source&folder=" +
+                            activefolder + "&entityModule=" +
+                            activemodule + "&session=" + session,
+                            join.add(function(reply) { 
+                                var found = false;
+                                if (reply && reply.data) {
+                                    for (var i=0; i < reply.data.length; i++) {
+                                        if (reply.data[i][3].match(/.google.calendar$/)) {
+                                            found = true;
+                                            newConfirm(_("Warning"),
+                                                    _("Please note: Refreshing this scubscription will overwrite your changes you've made in this folder and replace it with the content of the external calendar! Do you really want to continue?"),
+                                                    AlertPopup.YESNO, null, function() { join = lock = null; }, lock);
+                                            break;
+                                        }
+                                    }
+                                }
+                                if (!found) lock();
+                    }), lock);
+                } else {
+                    lock();
+                }
             };
         };
         
